@@ -99,19 +99,10 @@ class Scrobble(TimeStampedModel):
             f"Creating or updating scrobble for video {video} with data {jellyfin_data}"
         )
         scrobble = (
-            Scrobble.objects.filter(video=video, user_id=user_id)
+            cls.objects.filter(video=video, user_id=user_id)
             .order_by('-modified')
             .first()
         )
-        # Check if playback_position_ticks has changed from this scrobble
-        scrobble_changed = (
-            scrobble
-            and scrobble.playback_position_ticks
-            != jellyfin_data['playback_position_ticks']
-        )
-        if not scrobble_changed:
-            logger.info('Scrobble playback has not changed, not scrobbling')
-            return
 
         # Backoff is how long until we consider this a new scrobble
         backoff = timezone.now() + timedelta(minutes=VIDEO_BACKOFF)
@@ -127,7 +118,7 @@ class Scrobble(TimeStampedModel):
     ) -> "Scrobble":
         scrobble_data['track_id'] = track.id
         scrobble = (
-            Scrobble.objects.filter(track=track, user_id=user_id)
+            cls.objects.filter(track=track, user_id=user_id)
             .order_by('-modified')
             .first()
         )
